@@ -31,6 +31,16 @@ fn main() -> Result<()> {
 
             let stats = generate_files(comm)?;
 
+            if !stats.nodes_processed.is_empty() {
+                println!("\nGenerated docs for: ");
+                stats.nodes_processed.iter().for_each(|doc| {
+                    for node in doc.nodes.iter() {
+                        println!("{}", node.node_name);
+                    }
+                });
+                println!()
+            }
+
             println!(
                 "done. \n Processed: \n {} files \n {} directories \n in {}s",
                 stats.files_read,
@@ -50,9 +60,6 @@ fn main() -> Result<()> {
 
             println!("Successfully created {node_name}.doctor.toml");
         }
-        Commands::Verify { .. } => {
-            todo!()
-        }
     }
 
     Ok(())
